@@ -71,7 +71,9 @@ class MappingClass(click.ParamType):
         return entity_mapping
 
 
-@click.group(name="nlu", short_help='For short text classification and entity extraction')
+@click.group(
+    name="nlu", short_help="For short text classification and entity extraction"
+)
 def nlu():
     pass
 
@@ -89,7 +91,8 @@ def nlu_get_languages(log_level: Text):
 
 @nlu.command(
     name="convert-dataset",
-    help="To know more about the format and structure kindly refer https://docs.neuralspace.com",
+    help="To know more about the format and structure kindly refer to"
+    "https://docs.neuralspace.ai/natural-language-understanding/concepts/dataset-format-and-converters",
 )
 @click.option(
     "-F",
@@ -104,7 +107,7 @@ def nlu_get_languages(log_level: Text):
     is_flag=True,
     default=False,
     help="If the names of your entities are the same as our pretrained entities "
-         "then tag them automatically as pre-trained",
+    "then tag them automatically as pre-trained",
 )
 @click.option(
     "-L",
@@ -112,7 +115,7 @@ def nlu_get_languages(log_level: Text):
     type=click.STRING,
     required=True,
     help="Language in which the dataset is. "
-         "Use the following to get a list of supported languages: neuralspace nlu get-languages",
+    "Use the following to get a list of supported languages: neuralspace nlu get-languages",
 )
 @click.option(
     "-em",
@@ -120,10 +123,10 @@ def nlu_get_languages(log_level: Text):
     type=MappingClass(),
     required=False,
     help="If your entity names don't match with our pre-trained entity names then you can give a mapping like this:"
-         "'your_entity_name:ns_entity_name,...' and we will convert them to our format. "
-         "This argument works best with the --auto-tag-entities argument as it can happen in a "
-         "lot of cases that your entity names don't match our pre-trained entity names, "
-         "or even regex and lookup entities. This helps you make make the best out of the platform.",
+    "'your_entity_name:ns_entity_name,...' and we will convert them to our format. "
+    "This argument works best with the --auto-tag-entities argument as it can happen in a "
+    "lot of cases that your entity names don't match our pre-trained entity names, "
+    "or even regex and lookup entities. This helps you make make the best out of the platform.",
 )
 @click.option(
     "-t",
@@ -137,27 +140,29 @@ def nlu_get_languages(log_level: Text):
     "--input-path",
     required=True,
     multiple=True,
-    help="Name of the folder in which the dataset files are",
+    help="Name of the folder in which the dataset files are stored. "
+    "You can read more about dataset formats here https://docs.neuralspace.ai/natural-language-understanding/concepts/dataset-format-and-converters#dataset-format "  # noqa
+    "You can look at sample datasets here: https://github.com/Neural-Space/neuralspace-examples/tree/format_examples/datasets/nlu/Sample%20formats",  # noqa
 )
 @click.option(
     "-o",
     "--output-path",
     required=True,
-    help="Name of the folder in which the converted dataset files want to be stored",
+    help="Path to the folder in which the converted dataset files will be stored",
 )
 @click.option(
     "-ime",
     "--ignore-missing-examples",
     is_flag=True,
     default=False,
-    help="Will ignore if there is any missing examples in your data(works with csv files only)",
+    help="Will ignore if there are any missing examples in your data (works with CSV format only)",
 )
 @click.option(
     "-iswp",
     "--ignore-swapped-columns",
     is_flag=True,
     default=False,
-    help="Will ignore if there is swapped columns in your nlu examples data(works with csv files only)",
+    help="Will ignore if you have swapped columns in your nlu examples data (works with csv files only)",
 )
 @click.option(
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
@@ -241,6 +246,93 @@ def converter(
         )
 
 
+@nlu.command(
+    name="convert-huggingface-ner-dataset",
+)
+@click.option(
+    "-hf",
+    "--huggingface-dataset",
+    required=True,
+    type=click.STRING,
+    help="Exact name of the NER dataset from huggingface dataset hub",
+)
+@click.option(
+    "-s",
+    "--subset",
+    required=True,
+    type=click.STRING,
+    multiple=True,
+    help="Go to the dataset page on huggingface and pass all the subsets you want as shown in the dataset preview."
+    "For multiple subsets, pass them in one string seperated by space",
+)
+@click.option(
+    "-L",
+    "--language",
+    type=click.STRING,
+    required=True,
+    help="Language in which the dataset is. "
+    "Use the following to get a list of supported languages: neuralspace nlu get-languages"
+    "For datasets having more than one language, select 'multilingual'",
+)
+@click.option(
+    "-tr",
+    "--num-train-examples",
+    type=click.INT,
+    required=False,
+    default=-1,
+    help="Pass the number of examples you want in your converted training dataset for each subset"
+    "Dont set this parameter if you want to select all the examples available in the dataset",
+)
+@click.option(
+    "-te",
+    "--num-test-examples",
+    type=click.INT,
+    required=False,
+    default=-1,
+    help="Pass the number of examples you want in your converted test dataset for each subset"
+    "Dont set this parameter if you want to select all the examples available in the dataset",
+)
+@click.option(
+    "-o",
+    "--output-path",
+    required=True,
+    type=click.STRING,
+    help="Path to the folder in which the converted dataset files will be stored",
+)
+@click.option(
+    "-me",
+    "--max-entities",
+    required=False,
+    default=30,
+    type=click.INT,
+    help="Only keeps sentences having number of entities less than selected value."
+    "Sentences having more entities are discarded.",
+)
+def huggingface_converter(
+    huggingface_dataset: Text,
+    subset: List,
+    language: Text,
+    num_train_examples: int,
+    num_test_examples: int,
+    output_path: Text,
+    max_entities: int,
+):
+    from neuralspace.nlu.converters.huggingface_nerconverter import (
+        HuggingfaceNerConverter,
+    )
+
+    converter = HuggingfaceNerConverter(
+        language=language, max_entities_in_text=max_entities
+    )
+    converter.convert(
+        hf_dataset_name=huggingface_dataset,
+        subsets=list(subset),
+        num_train_examples=num_train_examples,
+        num_test_examples=num_test_examples,
+        output_directory=Path(output_path),
+    )
+
+
 @nlu.command(name="create-project")
 @click.option(
     "-p",
@@ -279,7 +371,7 @@ def nlu_create_project(project_name: Text, languages: List[Text], log_level: Tex
     "--project-id",
     type=click.STRING,
     required=True,
-    help="Project id",
+    help="id of the project you want to delete",
 )
 @click.option(
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
@@ -298,7 +390,7 @@ def nlu_delete_project(project_id: Text, log_level: Text):
     type=click.STRING,
     required=False,
     default="",
-    help="Substring search",
+    help="Substring search keyword",
 )
 @click.option(
     "-p",
@@ -358,7 +450,8 @@ def nlu_list_projects(
     "--dataset-file",
     type=click.Path(exists=True, dir_okay=False),
     required=True,
-    help="an nlu dataset file",
+    help="An nlu dataset file in NeuralSpace format. "
+    "To convert from other platforms like Rasa, Dialogflow, etc. try: ",
 )
 @click.option(
     "-p",
@@ -380,7 +473,8 @@ def nlu_list_projects(
     type=click.INT,
     required=False,
     default=0,
-    help="Skip this many example from the beginning",
+    help="Skip this many example from the beginning. "
+    "Use this in case you have to interrupt upload or if some error occurred while uploading.",
 )
 @click.option(
     "-e",
@@ -388,7 +482,7 @@ def nlu_list_projects(
     type=click.BOOL,
     required=False,
     default=False,
-    help="to ignore errors and go to the next example",
+    help="To ignore errors and go to the next example",
 )
 @click.option(
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
@@ -445,14 +539,14 @@ def nlu_upload_dataset(
     type=click.Choice(["train", "test"]),
     required=False,
     default="train",
-    help="Flag to filter only prepared examples",
+    help="Flag to filter only train or test examples",
 )
 @click.option(
     "-i",
     "--intent",
     type=click.STRING,
     required=False,
-    help="Flag to filter examples only in this intent",
+    help="Flag to filter examples only for this intent",
 )
 @click.option(
     "-n",
@@ -602,7 +696,7 @@ def nlu_train_model(
     type=click.INT,
     required=False,
     default=1,
-    help="Time to wait between consecutive pools.",
+    help="Time to wait between consecutive status-check pools.",
 )
 @click.option(
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
@@ -718,7 +812,7 @@ def nlu_delete_model(model_id: Text, log_level: Text):
     type=click.INT,
     required=False,
     default=1,
-    help="Number of replicas  to deploy for this model",
+    help="Number of replicas to deploy for this model. One Replica gives you 5-8 requests per second throughput.",
 )
 @click.option(
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
@@ -743,7 +837,7 @@ def nlu_deploy(model_id: Text, n_replicas: int, log_level: Text):
     "--input-text",
     type=click.STRING,
     required=True,
-    help="Number of replicas  to deploy for this model",
+    help="Text to parse",
 )
 @click.option(
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
